@@ -17,26 +17,26 @@ require Exporter;
 
 
 
-sub major($) {
+sub major {
     (($_[0]>>32)&0xFFFFF000) | (($_[0]>>8)&0x0FFF);
 }
 
 
-sub minor($) {
+sub minor {
     (($_[0]>>12)&0xFFFFFF00) | ($_[0]&0xFF);
 }
 
 
-sub makedev($$) {
+sub makedev {
     (($_[0]&0xFFFFF000)<<32) | (($_[0]&0x0FFF)<<8) |
         (($_[1]&0xFFFFFF00)<<12) | ($_[1]&0xFF);
 }
 
 
 
-sub mkdev($$) { #2017-12-19
+sub mkdev { #2017-12-19
     warn "mkdev is deprecated, use makedev instead\n";
-    return makedev($_[0], $_[1]);
+    return makedev(@_);
 }
 
 
